@@ -1,12 +1,5 @@
 package mail_test
 
-import (
-	"regexp"
-	"testing"
-
-	"github.com/emersion/go-message/mail"
-)
-
 const mailString = "Subject: Your Name\r\n" +
 	"Content-Type: multipart/mixed; boundary=message-boundary\r\n" +
 	"\r\n" +
@@ -40,11 +33,3 @@ const nestedMailString = "Subject: Fwd: Your Name\r\n" +
 	"\r\n" +
 	mailString +
 	"--outer-message-boundary--\r\n"
-
-func TestGenerateMessageID(t *testing.T) {
-	msgId := mail.GenerateMessageID()
-	regex := regexp.MustCompile(`^<.*@.*>$`)
-	if !regex.MatchString(msgId) {
-		t.Error("Generated message ID does not meet RFC requirement")
-	}
-}
